Index: ui/base/resource/resource_bundle.h |
diff --git a/ui/base/resource/resource_bundle.h b/ui/base/resource/resource_bundle.h |
index 1e6ca16d4135df2e7074a59001284558593aa8bb..b0e9cdb1738bf4fa6df2c116e1929eb90eff3ad4 100644 |
--- a/ui/base/resource/resource_bundle.h |
+++ b/ui/base/resource/resource_bundle.h |
@@ -132,12 +132,16 @@ class UI_BASE_EXPORT ResourceBundle { |
static std::string InitSharedInstanceLocaleOnly( |
const std::string& pref_locale, Delegate* delegate); |
// Initialize the ResourceBundle using given file. The second argument |
// controls whether or not ResourceBundle::LoadCommonResources is called. |
// This allows the use of this function in a sandbox without local file |
// access (as on Android). |
- static void InitSharedInstanceWithPakFile(base::File file, |
- bool should_load_common_resources); |
+ static void InitSharedInstanceWithPakFileRegion( |
+ base::File pak_file, |
+ const base::MemoryMappedFile::Region& region, |
+ bool should_load_common_resources); |
// Initialize the ResourceBundle using given data pack path for testing. |
static void InitSharedInstanceWithPakPath(const base::FilePath& path); |
@@ -132,12 +132,16 @@ class UI_BASE_EXPORT ResourceBundle { |
static std::string InitSharedInstanceLocaleOnly( |
const std::string& pref_locale, Delegate* delegate); |
- // Initialize the ResourceBundle using given file. The second argument |
- // controls whether or not ResourceBundle::LoadCommonResources is called. |
+ // Initialize the ResourceBundle using the given file region. If |region| is |
+ // MemoryMappedFile::Region::kWholeFile, the entire |pak_file| is used. |
+ // |should_load_common_resources| controls whether or not LoadCommonResources |
+ // is called. |
// This allows the use of this function in a sandbox without local file |
// access (as on Android). |